/*!
 * @file network_monitor.h
 *  a class to monitor the network: throughput, network nodes
 */

#ifndef _NETWORK_MONITOR_H
#define _NETWORK_MONITOR_H

#include "base_object.h"
#include "synchronizeable.h"

#include <list>

class NetworkStream;
class PeerInfo;
class NetworkNode;

namespace OrxGui { class GLGuiBox; };



//!< a class that monitors the whole network. it tries to gather all informations its able to from the network
class NetworkMonitor : public Synchronizeable
{

  public:
    NetworkMonitor(NetworkStream* networkStream);
    virtual ~NetworkMonitor();

    /* client/masterserver/proxyserver addition/removal interface */
    void addNetworkNode(NetworkNode* node);
    void removeNetworkNode(NetworkNode* node);

    void addClient(PeerInfo* node);
    void addProxyServer(PeerInfo* node);
    void addMasterServer(PeerInfo* node);

    void removeClient(PeerInfo* node);
    void removeProxyServer(PeerInfo* node);
    void removeMasterServer(PeerInfo* node);


    void showGUI();
    void hideGUI();

    void process();


  private:
    std::list<NetworkNode*>      nodeList;                   //!< list of all network nodes

    OrxGui::GLGuiBox*            box;

    int                          playerNumber;                 //!< total number of players in the game
};


#endif
